#!/bin/sh

if [ "$1" = "-c" ]; then
	echo "yum check-update"
	yum check-update
	rm -f /tmp/query-available.gyum
fi
if [ "$1" = "-a" ]; then
	retval=0
	if [ ! -f /tmp/query-available.gyum ]; then
		echo "Loading available packages"
		yum info available > /tmp/query-available.gyum
		retval=$?
		if [ "$retval" != "0" ]; then
			rm -f /tmp/query-available.gyum
		fi
	fi
	if [ "$retval" = "0" ]; then
    	    echo "Loading installed packages"
	    echo "Installed Packages" > /tmp/query-installed.gyum
	    rpm -qa --queryformat "Name   :%{NAME}\nArch   :%{ARCH}\nVersion:%{VERSION}\nRelease:%{RELEASE}\nSize   :%{SIZE}\nRepo   :installed\nSummary:%{SUMMARY}\n\nDescription:\n%{DESCRIPTION}\n\n" >> /tmp/query-installed.gyum
	    retval=$?
	fi
fi
if [ "$1" = "-i" ]; then
	echo "Loading installed packages"
	echo "Installed Packages" > /tmp/query-installed.gyum
	rpm -qa --queryformat "Name   :%{NAME}\nArch   :%{ARCH}\nVersion:%{VERSION}\nRelease:%{RELEASE}\nSize   :%{SIZE}\nRepo   :installed\nSummary:%{SUMMARY}\n\nDescription:\n%{DESCRIPTION}\n\n" >> /tmp/query-installed.gyum
	retval=$?
fi
if [ "$1" = "-pi" ]; then
	if [ "$2" = "-p" ]; then
		param="-p"
		name=$3
	else
		param=""
		name=$2
	fi
	echo "Loading information: "$name
	rpm -q --queryformat "name:%{NAME}\nversion:%{VERSION}\nrelease:%{RELEASE}\ngroup:%{GROUP}\ninstall_date:%{INSTALLTIME}\nsummary:%{SUMMARY}\nlicense:%{LICENSE}\nbuild_host:%{BUILDHOST}\nbuild_date:%{BUILDTIME}\nvendor:%{VENDOR}\npackager:%{PACKAGER}\nurl:%{URL}\nsize:%{SIZE}\nsignature:pgp=%{SIGPGP},md5=%{SIGMD5}\nMdescription:%{DESCRIPTION}\n++---++\nMconflicts:" --conflicts --queryformat "\n++---++\nMchangelog:" --changelog --queryformat "\n++---++\nMrequires:" -R --queryformat "\n++---++\nMfiles:" -l $param $name > /tmp/query-rpm.gyum
	retval=$?
fi
if [ "$1" = "-pf" ]; then
	echo "rpm -q --queryformat %{NAME} -f "$2
	rpm -q --queryformat %{NAME} -f $2 > /tmp/query-package.gyum
	retval=$?
fi
if [ "$1" = "-f" ]; then
	mkdir -p $2 && cd $2 && rpm2cpio $3 | cpio -i -d .$4
	retval=$?
fi
if [ "$1" = "-e" ]; then
	if [ "$2" = "--without-dir" ]; then
		mkdir -p /tmp/gnome-yum/.extract && cd /tmp/gnome-yum/.extract && rpm2cpio $4 | cpio -i -m -d .$5/$6
		mv /tmp/gnome-yum/.extract$5/$6 $3 && rm -rf /tmp/gnome-yum/.extract
	else
		mkdir -p $3 && cd $3 && rpm2cpio $4 | cpio -i -m -d .$5/$6
	fi
	retval=$?
fi
exit $retval
